package handles

import (
	"net/http"

	"github.com/louisevanderlith/comment/core"
	"github.com/louisevanderlith/comment/core/commenttype"
	"github.com/louisevanderlith/droxolite/context"
	"github.com/louisevanderlith/husk"
)

type Types struct {
}

func (x *Types) Get(ctx context.Requester) (int, interface{}) {
	return http.StatusMethodNotAllowed, nil
}

func (x *Types) View(ctx context.Requester) (int, interface{}) {
	commentType := commenttype.GetEnum(ctx.FindParam("type"))
	nodeKey, err := husk.ParseKey(ctx.FindParam("nodeID"))

	if err != nil {
		return http.StatusBadRequest, err
	}

	result, err := core.GetNodeMessage(nodeKey, commentType)

	if err != nil {
		return http.StatusInternalServerError, err
	}

	return http.StatusOK, result
}

// @Title Create Comment
// @Description Creates a comment
// @Param	body		body 	logic.MessageEntry	true		"comment entry"
// @Success 200 {map[string]string} map[string]string
// @Failure 403 body is empty
// @router / [post]
func (x *Types) Create(ctx context.Requester) (int, interface{}) {
	var entry core.Message
	err := ctx.Body(&entry)

	if err != nil {
		return http.StatusBadRequest, err
	}

	entry.UserKey = ctx.GetMyUser().UserKey
	err = entry.SubmitMessage()

	if err != nil {
		return http.StatusInternalServerError, err
	}

	return http.StatusOK, "Comment Created"
}

func (x *Types) Update(ctx context.Requester) (int, interface{}) {
	key, err := husk.ParseKey(ctx.FindParam("key"))

	if err != nil {
		return http.StatusBadRequest, err
	}

	body := core.Message{}
	err = ctx.Body(&body)

	if err != nil {
		return http.StatusBadRequest, err
	}

	err = core.UpdateMessage(key, body)

	if err != nil {
		return http.StatusInternalServerError, err
	}

	return http.StatusOK, "Saved"
}
